#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const data_source_1 = require("./database/data_source");
const index_1 = require("./generated/index");
const callbacks_1 = require("./util/callbacks");
const express_winston_1 = __importDefault(require("express-winston"));
const requestHandler_1 = require("./util/requestHandler");
const service_common_1 = require("@crosslab/service-common");
data_source_1.AppDataSource.initialize()
    .then(() => {
    index_1.app.use(express_winston_1.default.logger({
        winstonInstance: requestHandler_1.logger,
        meta: true,
        msg: "HTTP {{res.statusCode}} {{req.method}} {{res.responseTime}}ms {{req.url}}",
        expressFormat: true,
        colorize: false,
        ignoreRoute: function (_req, _res) { return false; },
        requestFilter: (req, propName) => {
            if (propName === "headers" && req.headers.authorization)
                return {
                    ...req.headers,
                    authorization: "HIDDEN"
                };
            return req[propName];
        }
    }));
    index_1.app.initService({
        security: {
            "JWT": (0, service_common_1.JWTVerify)(config_1.config)
        },
        additionalHandlers: [
            callbacks_1.callbackHandling
        ]
    });
    index_1.app.listen(config_1.config.PORT);
})
    .catch((err) => {
    console.error('Error during Data Source initialization:', err);
});
//# sourceMappingURL=index.js.map