"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.establishPeerconnections = void 0;
const create_1 = require("../database/methods/create");
const save_1 = require("../database/methods/save");
const errors_1 = require("../types/errors");
const api_1 = require("./api");
const callbacks_1 = require("./callbacks");
const connectionPlan_1 = require("./connectionPlan");
/**
 * This function attempts to establish the peerconnections for an experiment model according to its connection plan.
 * @param experimentModel The experiment model for which to establish the peerconnections.
 */
async function establishPeerconnections(requestHandler, experimentModel) {
    const peerconnectionPlans = requestHandler.executeSync(connectionPlan_1.buildConnectionPlan, experimentModel);
    for (const peerconnectionPlan of peerconnectionPlans) {
        // TODO: error handling
        const peerconnection = await requestHandler.executeAsync(api_1.createPeerconnection, peerconnectionPlan, {
            closedUrl: callbacks_1.callbackUrl,
            statusChangedUrl: callbacks_1.callbackUrl
        });
        if (!experimentModel.connections)
            experimentModel.connections = [];
        if (!peerconnection.url)
            requestHandler.throw(errors_1.MissingPropertyError, 'Created peerconnection does not have a url', 500);
        if (!peerconnection.devices)
            requestHandler.throw(errors_1.MissingPropertyError, 'Created peerconnection does not have devices', 500);
        if (!peerconnection.devices[0].url || !peerconnection.devices[1].url)
            requestHandler.throw(errors_1.MissingPropertyError, 'Created peerconnection has a device without an url', 500);
        callbacks_1.peerconnectionClosedCallbacks.push(peerconnection.url);
        callbacks_1.peerconnectionStatusChangedCallbacks.push(peerconnection.url);
        // create, push and save new peerconnection
        const peerconnectionModel = requestHandler.executeSync(create_1.createPeerconnectionModel, peerconnection.url);
        experimentModel.connections.push(peerconnectionModel);
        await requestHandler.executeAsync(save_1.saveExperimentModel, experimentModel);
    }
}
exports.establishPeerconnections = establishPeerconnections;
//# sourceMappingURL=peerconnection.js.map